@@ -22,9 +22,10 @@ HTML = """
 class S3DirectEditor(widgets.TextInput):
 
     class Media:
-        js = (
+        js = {
+            's3direct/js/require.js',
             's3direct/js/s3direct.js',
-        )
+        }
         css = {
             'all': (
                 's3direct/css/bootstrap-progress.min.css',
